.. _API_Documentation:

API Documentation
=================

Comprehensive reference material for most of the public API exposed by Cromwell-tools:

cromwell_tools.cromwell_api
---------------------------

.. automodule:: cromwell_tools.cromwell_api
   :members:
   :inherited-members:

cromwell_tools.cromwell_auth
----------------------------

.. automodule:: cromwell_tools.cromwell_auth
   :members:
   :inherited-members:

cromwell_tools.utilities
------------------------

.. automodule:: cromwell_tools.utilities
   :members:
   :inherited-members:

cromwell_tools.cli
------------------

.. automodule:: cromwell_tools.cli
   :members:
   :inherited-members:
